#!/bin/sh

starship() {
	echo "Installing Starship configuration..."
	ln -sf $PWD/starship/starship.toml ~/.config/starship.toml
}

alacritty() {
	echo "Installing Alacritty configuration..."
	ln -sf $PWD/alacritty $HOME/.config/alacritty
}

gitconfg() {
	echo "Installing git aliases..."
	git config --global alias.pushup 'push -u origin HEAD'
	git config --global alias.please 'push --force-with-lease'
	git config --global alias.new-branch 'checkout -b'
	git config --global alias.slog 'log --oneline --decorate'
}

bat() {
	echo "Installing Bat configuration..."
	BAT_CONFIG_FILE=`bat --config-file`
	mkdir -p `dirname $BAT_CONFIG_FILE`
	ln -sf $PWD/bat/config $BAT_CONFIG_FILE
}

nvim() {
	echo "Installing NeoVim configuration..."
	mkdir -p $HOME/.config 2> /dev/null
	ln -sf $PWD/nvim $HOME/.config
	cd $HOME/.config/nvim
	git submodule init
	git submodule update
	cd -
}

emacs() {
	echo "Installing Emacs configuration..."
	ln -sf $PWD/emacs.d $HOME/.emacs.d
}

fish() {
	echo "Installing Fish configuration..."
	mkdir -p $HOME/.config 2> /dev/null
	ln -sf $PWD/fish $HOME/.config/
}

tmux() {
	echo "Installing Tmux configuration..."
	ln -sf $PWD/tmux/tmux.conf $HOME/.tmux.conf
	git clone https://github.com/tmux-plugins/tpm $HOME/.tmux/plugins/tpm
}

rust() {
	echo "Installing Rust and things..."
	curl --proto '=https' --tlsv1.2 -sSf https://sh.rustup.rs | sh -s -- -y
	$HOME/.cargo/bin/cargo install exa
	$HOME/.cargo/bin/cargo install bat
	$HOME/.cargo/bin/cargo install starship
	$HOME/.cargo/bin/cargo install skim
	$HOME/.cargo/bin/cargo install fd-find
	$HOME/.cargo/bin/cargo install ripgrep
}

rust
nvim
emacs
starship
fish
alacritty
gitconfg
tmux
